@@ -40,6 +40,18 @@ char *   cmddialog_run            (GtkWindow    *gw_parent,
                                    const char   *s_current_cmd,
                                    const GSList *gsl_iinfo);
 /*----------------------------------------------------------------------------*/
+/**
+ * @brief  Dialog with other settings.
+ *
+ * @param[in] gw_parent  Parent window
+ * @param[in] s_cfg_file Path to config file
+ * @param[in] s_fn       Path to sample wallpaper file
+ * @return    none
+ */
+void     other_settings_dialog    (GtkWindow  *gw_parent,
+                                   const char *s_cfg_file,
+                                   const char *s_fn);
+/*----------------------------------------------------------------------------*/
 /**
  * @fn  GList  * add_images_from_web_dilaog (GtkWindow  *gw_parent,
  *                                           const char *s_cfg_file)
